@@ -3,7 +3,7 @@
 
 """
    @project: HSPyLib
-   @Package: main.exception
+   @package: hspylib.core.exception
       @file: exceptions.py
    @created: Tue, 4 May 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
