@@ -3,7 +3,7 @@
 
 """
    @project: hspylib
-   @package: hspylib.main.hspylib
+   @package: hspylib.core.metaclass
       @file: __classpath__.py
    @created: Wed, 8 Jun 2022
     @author: "<B>H</B>ugo <B>S</B>aporetti <B>J</B>unior")"
